@@ -5,7 +5,6 @@ if (isset($_SERVER['SERVER_SOFTWARE']) && strpos($_SERVER['SERVER_SOFTWARE'], 'G
 }
 
 require_once "init.php";
-require_once "templating.php";
 
 $blog_feed_max_items = getconfig("blog_feed_max_items");
 if ($blog_feed_max_items === false) {
@@ -33,9 +32,9 @@ echo '<rss version="2.0">';
 echo "\n";
 
 echo "<channel>";
-echo "<title>" . getconfig("homepage_title") . "</title>\n";
+echo "<title>" . Settings::getLang("homepage_title", $lang) . "</title>\n";
 echo "<link>" . rootDirectory() . "</link>\n";
-echo "<description>" . getconfig("motto") . "</description>\n";
+echo "<description>" .  Settings::getLang("motto", $lang) . "</description>\n";
 
 if (! getconfig("hide_meta_generator")) {
     $generator = "UliCMS " . cms_version();
