@@ -52,14 +52,9 @@ function blog_render() {
 function blog_update() {
 	$acl = new ACL ();
 	$html_output = "";
-	$doSpellCheck = isset ( $_POST ["spellcheck"] );
 	
 	$title = $_POST ["title"];
 	
-	if ($doSpellCheck) {
-		$title = SpellChecker::autoCorrectCommonTypos ( $title );
-	}
-	
 	$title = db_escape ( $title );
 	
 	$seo_shortname = db_escape ( $_POST ["seo_shortname"] );
@@ -85,11 +80,6 @@ function blog_update() {
 	
 	$content_preview = $_POST ["content_preview"];
 	
-	if ($doSpellCheck) {
-		$content_full = SpellChecker::autoCorrectCommonTypos ( $content_full );
-		$content_preview = SpellChecker::autoCorrectCommonTypos ( $content_preview );
-	}
-	
 	$content_full = db_escape ( $content_full );
 	$content_preview = db_escape ( $content_preview );
 	
@@ -143,14 +133,9 @@ function blog_submit() {
 	$acl = new ACL ();
 	$html_output = "";
 	
-	$doSpellCheck = isset ( $_POST ["spellcheck"] );
 	
 	$title = $_POST ["title"];
 	
-	if ($doSpellCheck) {
-		$title = SpellChecker::autoCorrectCommonTypos ( $title );
-	}
-	
 	$title = db_escape ( $title );
 	
 	$seo_shortname = db_escape ( $_POST ["seo_shortname"] );
@@ -176,11 +161,6 @@ function blog_submit() {
 	
 	$content_preview = $_POST ["content_preview"];
 	
-	if ($doSpellCheck) {
-		$content_full = SpellChecker::autoCorrectCommonTypos ( $content_full );
-		$content_preview = SpellChecker::autoCorrectCommonTypos ( $content_preview );
-	}
-	
 	$content_full = db_escape ( $content_full );
 	
 	$content_preview = db_escape ( $content_preview );
